@@ -11,7 +11,6 @@ public_api = [
     'Socket',
     'Frame',
     'Message',
-    'device',
     'proxy',
     'proxy_steerable',
     'zmq_poll',
@@ -33,8 +32,9 @@ def select_backend(name: str) -> Dict:
         raise
     except Exception as e:
         raise ImportError(f"Importing {name} failed with {e}") from e
-
-    ns = {}
-    for key in public_api:
-        ns[key] = getattr(mod, key)
+    ns = {
+        # private API
+        'monitored_queue': mod.monitored_queue,
+    }
+    ns.update({key: getattr(mod, key) for key in public_api})
     return ns
